@@ -966,6 +966,17 @@ class Base_Page(Borg, unittest.TestCase):
             self.exceptions.append("An exception occurred when hitting enter")
             return None
 
+    def hit_down(self, locator, wait_time=0.5):
+        "Hit enter"
+        try:
+            element = self.get_element(locator)
+            element.send_keys(Keys.ARROW_DOWN)
+            self.wait(wait_time)
+        except Exception as e:
+            self.write(str(e), 'debug')
+            self.exceptions.append("An exception occurred when hitting enter")
+            return None
+
     def scroll_down(self, locator, wait_time=0.5):
         "Scroll down"
         try:
